@@ -1,10 +1,11 @@
 from datetime import datetime
 from typing import List, Optional
 
-from pydantic import AnyUrl, BaseModel, EmailStr
+from pydantic import AnyUrl, EmailStr
+from fa_common.models import CamelModel
 
 
-class AuthUser(BaseModel):
+class AuthUser(CamelModel):
     sub: str
     name: str = "Unknown User"
     email: Optional[EmailStr]
